@@ -1,7 +1,8 @@
 #!/usr/bin/python
 # -*- coding: UTF-8 -*-
+import os
 
-quant1x_home = '~/.quant1x'
+quant1x_home = os.path.expanduser('~/.quant1x')
 quant1x_data = quant1x_home + '/data'
 quant1x_data_cn = quant1x_data + '/cn'
 quant1x_data_hk = quant1x_data + '/hk'
